@@ -1,85 +1,77 @@
-''' Module Information
------------------------------------------------------------
-Purpose of module: Computes the equilibrium solution of a plate model using finite elements and stores the results.
------------------------------------------------------------
-- Copywrite Tobia Diggelmann (ETH Zurich) 30.05.2021
+'''
+<a name="solveModel"></a>Computes the equilibrium solution of a plate model using finite elements and stores the results.
 '''
 #Basic modules
 import numpy as np
-# import pandas as pd
-# from scipy import sparse
-# from scipy.sparse import linalg
 from scipy.linalg import ldl
 from scipy.linalg import solve
 from scipy.sparse.linalg import spsolve
 from scipy.sparse import csr_matrix
 from scipy.integrate import trapezoid
-
 # Import custom functions from other modules
-from .shapeFunctions import *
-from .localMatrixes import *
-from .internalForces import *
-from .slicingFunctions import *
-from .rotationMatrix import *
-from .displayModel import plotInputGeometry, plotMesh
-
+from ._shapeFunctions import *
+from ._localMatrixes import *
+from ._internalForces import *
+from ._slicingFunctions import *
+from ._rotationMatrix import *
+from .displayModel import plotInputGeometry
 import gmsh
-
 # for debug purposes
 from tqdm import tqdm
 
-def solveModel(self, resultsScales = (1e-3, 1, 1),\
+def solveModel(self, resultsScales = (1, 1, 1),\
     internalForcePosition = 'center', smoothedValues = False, computeMoments=True, kBendingResistance = 1):
-    ''' Given a plateModel object with an initialized mesh, this function computes displacements, rotations and internal forces at
-        each node.\n
-            Input: \n
-            * self: plateModel object. \n
-            * resultsScales = (1e-3, 1, 1): Before being displayed the computed displacements are multiplied by resultsScales[0], the computed beding moments are multiplied by resultsScales[1]
-                and the shear forces by resultsScales[2]. \n
-            * internalForcePosition = 'center': String defining the desired position where the internal forces should be computed.
-            Possible values are "center" (default), "nodes" and "intPoints" for the positions used in the Gauss quadrature.\n
-            * smoothedValues = False: Experimental. If True, the values of the shear forces by displacement based elements are smoothed according to
-            the values at the Gauss points. \n
-            * computeMoments = True: Deactivates the computation of internal forces. For debug purposes. \n
-            * kBendingResistance = 1: 1/tan(alpha), to compute the plate bending resistance according to the SIA 262 swiss norm. \n
-            Return: \n
-            * outPos: (nNodes x 2) numpy matrix, with the x-y coordinates of the result points for the displacements. \n
-            * values: (nNodes x 3) numpy matrix, with the values of (vertical displacement, rotation 1, rotation 2) at each position in outPos.
+    ''' Given a `PlateModel` object with an initialized mesh, this function computes displacements, rotations and internal forces at
+        each node.
+        ~~~~~~~~~~~~~~~~~~~
+        INPUT
+        ~~~~~~~~~~~~~~~~~~~
+        * **self**: `PlateModel` object. 
+        * **resultsScales = (1e-3, 1, 1)**: Before being displayed the computed displacements are multiplied by resultsScales[0], the computed beding moments are multiplied by resultsScales[1]
+            and the shear forces by resultsScales[2]. 
+        * **internalForcePosition = 'center'**: String defining the desired position where the internal forces should be computed.
+        Possible values are "center" (default), "nodes" and "intPoints" for the positions used in the Gauss quadrature.
+        * **smoothedValues = False**: Experimental. If True, the values of the shear forces by displacement based elements are smoothed according to
+        the values at the Gauss points. 
+        * **computeMoments = True**: Deactivates the computation of internal forces. For debug purposes. 
+        * **kBendingResistance = 1**: 1/tan(alpha), to compute the plate bending resistance according to the SIA 262 swiss norm. 
+        ~~~~~~~~~~~~~~~~~~~
+        RETURN
+        ~~~~~~~~~~~~~~~~~~~
+        * **ResultsDictionary**: Dictionary with `Result` objects.
     '''
 
-    #chose the right solving algorithm based on the presence or not of downstand beams
+    # chose the right solving algorithm based on the presence or not of downstand beams
     if len(self.downStandBeams)>0:
         solveMethod='cho'
     else:
         solveMethod = 'sparse'
-    # Loop over elements and assemble stiffness matrices
+
+    # re-import mesh information
     nodes=self.mesh.nodesArray
-    # print('nodes: ', nodes)
     nNodesTotal = nodes.shape[0]
     nodesRotations = self.mesh.nodesRotations # both dataframes
     elementsList = self.mesh.elementsList
     BCs = self.mesh.BCs
     nGDofs = nodes.shape[0]*3
     p=self.loads[0]   
-
     platesList = self.plates
     downStandBeamsList = self.downStandBeams
     modelMesh = self.mesh
 
+    # for elastic vertical displacement of walls (experimental)
     elasticallySupportedNodes = self.mesh.elasticallySupportedNodes
     if len(self.walls)>0:
         if self.walls[0].isElasticallySupported:
-            wallStiffness = self.walls[0].body.eModule / self.walls[0].high * self.walls[0].thickness *0.007 # what is the characteristic length?
+            wallStiffness = self.walls[0].body.eModule / self.walls[0].high * self.walls[0].thickness *0.004 # what is the characteristic length?
         else:
             wallStiffness = None
     else:
         wallStiffness = None
 
-    sparseGlobalMatrix, sparseForceGlobal, discartedDOFs = getGlobalStiffnesAndForce(elementsList,platesList,downStandBeamsList, nodesRotations, modelMesh,p, nNodesTotal, elasticallySupportedNodes,wallStiffness)
-    # print(sparseForceGlobal.toarray())
-    # np.savetxt('K.csv', sparseGlobalMatrix.toarray(), delimiter=",")
+    sparseGlobalMatrix, sparseForceGlobal, discartedDOFs = _getGlobalStiffnesAndForce(elementsList,platesList,downStandBeamsList, nodesRotations, modelMesh,p, nNodesTotal, elasticallySupportedNodes,wallStiffness)
     elementType = elementsList[0].type
-    fDofsInt, rDofsBool,keepedDisplacements = getFreeDOFvector(BCs, nGDofs,elementType,discartedDOFs)
+    fDofsInt, rDofsBool,keepedDisplacements = _getFreeDOFvector(BCs, nGDofs,elementType,discartedDOFs)
 
     kMatFree = sparseGlobalMatrix[fDofsInt,:]
     kMatFree = kMatFree[:,fDofsInt]
@@ -87,13 +79,14 @@ def solveModel(self, resultsScales = (1e-3, 1, 1),\
 
     if solveMethod == 'cho':
         AmatList = self.mesh.AmatList
-        A = assembleSystemMFCmatrix(AmatList)
+        A = _assembleSystemMFCmatrix(AmatList)
         try:
             A=A[:,fDofsInt]
         except:
             raise ValueError('Please change solveMethod from "cho" to "sparse"')
 
-        M, rightSide = getMmatrixAndRightSide(A, kMatFree,fVecFree)# M is the matrix used to solve the system using lagrangian MPC. It has form [[K, A.T],[A, 0]]
+        M, rightSide = _getMmatrixAndRightSide(A, kMatFree,fVecFree)
+        # M is the matrix used to solve the system using lagrangian MPC. It has form [[K, A.T],[A, 0]]
         
         lu, d, _ = ldl(M)
         y = solve(lu, rightSide)
@@ -105,9 +98,6 @@ def solveModel(self, resultsScales = (1e-3, 1, 1),\
         uGlob[fDofsInt]=np.expand_dims(Uf, axis=1)
 
     elif solveMethod == 'sparse':
-        # KTEST = kMatFree.toarray()
-        # FTEST = fVecFree.toarray()
-        # sol = np.linalg.solve(KTEST,FTEST)
         Uf = spsolve(kMatFree,fVecFree)
         Uf=Uf.reshape(-1,1)
         uGlob=np.zeros((nGDofs,1))
@@ -133,14 +123,13 @@ def solveModel(self, resultsScales = (1e-3, 1, 1),\
     values[:,2]=uGlob[2::3,0]
 
     resultsDictionary = {}
-    resultsDictionary['vDisp'] = Result(outPos[:,0], outPos[:,1], vDisp, resultsScales[0])
-    resultsDictionary['xRot'] = Result(outPos[:,0], outPos[:,1], values[:,1], resultsScales[0])
-    resultsDictionary['yRot'] = Result(outPos[:,0], outPos[:,1], values[:,2], resultsScales[0])
-
+    resultsDictionary['vDisp'] = _Result(outPos[:,0], outPos[:,1], vDisp, resultsScales[0])
+    resultsDictionary['xRot'] = _Result(outPos[:,0], outPos[:,1], values[:,1], resultsScales[0])
+    resultsDictionary['yRot'] = _Result(outPos[:,0], outPos[:,1], values[:,2], resultsScales[0])
     self.resultsInformation = ResultsInformation()
     self.resultsInformation.uGlobPlate = uGlob
 
-    #compute MOMENTS
+    #compute internal forces
     if computeMoments:
         nodesArray = self.mesh.nodesArray
         mitcList = self.mesh.plateElementsList
@@ -149,34 +138,34 @@ def solveModel(self, resultsScales = (1e-3, 1, 1),\
         xPos = internalForcesPositions[:,0]
         yPos = internalForcesPositions[:,1]
 
-        resultsDictionary['Mx'] = Result(xPos,yPos,bendingMoments[:,0], resultsScales[1])
-        resultsDictionary['My'] = Result(xPos,yPos,bendingMoments[:,1], resultsScales[1])
-        resultsDictionary['Mxy'] = Result(xPos,yPos,bendingMoments[:,2], resultsScales[1])
-        resultsDictionary['Vx'] = Result(xPos,yPos,shearForces[:,0], resultsScales[2])
-        resultsDictionary['Vy'] = Result(xPos,yPos,shearForces[:,1], resultsScales[2])
+        resultsDictionary['Mx'] = _Result(xPos,yPos,bendingMoments[:,0], resultsScales[1])
+        resultsDictionary['My'] = _Result(xPos,yPos,bendingMoments[:,1], resultsScales[1])
+        resultsDictionary['Mxy'] = _Result(xPos,yPos,bendingMoments[:,2], resultsScales[1])
+        resultsDictionary['Vx'] = _Result(xPos,yPos,shearForces[:,0], resultsScales[2])
+        resultsDictionary['Vy'] = _Result(xPos,yPos,shearForces[:,1], resultsScales[2])
 
-        # self.results.resultsScales = resultsScales
-        bendingResistance = getBendingResistance(bendingMoments,kBendingResistance)
-        resultsDictionary['Mx_Rd_+'] = Result(xPos,yPos,bendingResistance[:,0,0], resultsScales[1])
-        resultsDictionary['My_Rd_+'] = Result(xPos,yPos,bendingResistance[:,1,0], resultsScales[1])
+        # store required bending resistance according to SIA262
+        bendingResistance = _getBendingResistance(bendingMoments,kBendingResistance)
+        resultsDictionary['Mx_Rd_+'] = _Result(xPos,yPos,bendingResistance[:,0,0], resultsScales[1])
+        resultsDictionary['My_Rd_+'] = _Result(xPos,yPos,bendingResistance[:,1,0], resultsScales[1])
 
-        resultsDictionary['Mx_Rd_-'] = Result(xPos,yPos,bendingResistance[:,0,1], resultsScales[1])
-        resultsDictionary['My_Rd_-'] = Result(xPos,yPos,bendingResistance[:,1,1], resultsScales[1])
+        resultsDictionary['Mx_Rd_-'] = _Result(xPos,yPos,bendingResistance[:,0,1], resultsScales[1])
+        resultsDictionary['My_Rd_-'] = _Result(xPos,yPos,bendingResistance[:,1,1], resultsScales[1])
 
-        resultsDictionary['Mx_Rd_max'] = Result(xPos,yPos,bendingResistance[:,0,2], resultsScales[1])
-        resultsDictionary['My_Rd_max'] = Result(xPos,yPos,bendingResistance[:,1,2], resultsScales[1])
+        resultsDictionary['Mx_Rd_max'] = _Result(xPos,yPos,bendingResistance[:,0,2], resultsScales[1])
+        resultsDictionary['My_Rd_max'] = _Result(xPos,yPos,bendingResistance[:,1,2], resultsScales[1])
 
         if len(self.downStandBeams) > 0:
             uzList = self.downStandBeams[0].elementsList
             Nforces, Vforces, Mforces, internalForcesPositions = getInternalForcesDSB(uzList,uDownStandBeam,internalForcePosition, self.downStandBeams[0])
-            resultsDictionary['N_DSB'] = Result(internalForcesPositions[:,0], internalForcesPositions[:,1], Nforces, resultsScales[2])
-            resultsDictionary['V_DSB'] = Result(internalForcesPositions[:,0], internalForcesPositions[:,1], Vforces, resultsScales[2])
-            resultsDictionary['N_DSB'] = Result(internalForcesPositions[:,0], internalForcesPositions[:,1], Mforces, resultsScales[1])
+            resultsDictionary['N_DSB'] = _Result(internalForcesPositions[:,0], internalForcesPositions[:,1], Nforces, resultsScales[2])
+            resultsDictionary['V_DSB'] = _Result(internalForcesPositions[:,0], internalForcesPositions[:,1], Vforces, resultsScales[2])
+            resultsDictionary['N_DSB'] = _Result(internalForcesPositions[:,0], internalForcesPositions[:,1], Mforces, resultsScales[1])
 
     self.resultsInformation.resultsDictionary = resultsDictionary
     return resultsDictionary
 
-def getGlobalStiffnesAndForce(elementsList,platesList,downStandBeamsList, nodesRotations, modelMesh,p,nNodesTotal, elasticallySupportedNodes,wallStiffness):
+def _getGlobalStiffnesAndForce(elementsList,platesList,downStandBeamsList, nodesRotations, modelMesh,p,nNodesTotal, elasticallySupportedNodes,wallStiffness):
     ''' Computes global stifness matrix and global force matrixes in sparse form.\n
         Input: \n
             * elementsList: List of element objects. \n
@@ -186,6 +175,8 @@ def getGlobalStiffnesAndForce(elementsList,platesList,downStandBeamsList, nodesR
             * modelMesh: mesh object of the plateModel object. \n
             * p: load object.
             * nNodesTotal: nodesArray.shape[0], number of nodes in the entire model.\n
+            * elasticallySupportedNodes: Array containing the nodes of the walls vertically elastic. \n
+            * wallStiffness: value of the vertical stiffness of the wall.
         Return: \n
             * sparseGlobalMatrix: Scipy sparse matrix of the system's stiffness.
             * sparseForceGlobal: Scipy sparse matrix of the system's force vector.
@@ -218,9 +209,6 @@ def getGlobalStiffnesAndForce(elementsList,platesList,downStandBeamsList, nodesR
             Df = platesList[plateOfTheElement].Df
             Dc = platesList[plateOfTheElement].Dc
             kLocalNotRotated,fLocal = GetLocalMatrix(xi, yi, Df,Dc,p,nNodes , elementType, elementIntegration)
-            # print('connectivity:', elemNodes)
-            # print('kLocalNotRotated', kLocalNotRotated)
-            
         else:
             Emod = downStandBeamsList[0].body.eModule
             Gmod = downStandBeamsList[0].body.gModule
@@ -231,22 +219,17 @@ def getGlobalStiffnesAndForce(elementsList,platesList,downStandBeamsList, nodesR
             Ds = 5/6*Gmod*crossA
             kLocalNotRotated, fLocal = gettimoBeamMatrix(xi, yi,Dc, Db, Ds, 0, nNodes)
 
+        # If the force is not on the entire plate's area, the local force vector has to be deleted and re-calculated
         if p.case != "area":
             fLocal = np.zeros((fLocal.size,1))
 
         R = getRotationMatrix(elementType, elemNodesRotations) 
-        # print('elemNodesRotations: ',elemNodesRotations)
-        # np.savetxt('R.csv', R, delimiter=",")
-
-
         element.rotationMatrix = R
         if elementType!='timo':
             modelMesh.plateElementsList[k].rotationMatrix = R
-
-        # #rotate stiffness matrix
+        # rotate stiffness matrix
         kTemp = np.matmul(kLocalNotRotated, R)
         kLocal = np.matmul(R.transpose(), kTemp)
-        # print('kLocal', kLocal)
         if elementType == 'timo':
             kLocal = kLocalNotRotated
 
@@ -254,8 +237,7 @@ def getGlobalStiffnesAndForce(elementsList,platesList,downStandBeamsList, nodesR
         kCoeff, discartedDOF = getKCoeff(elementType, coherentElemNodes)
         if discartedDOF != None:
             discartedDOFs[k]=discartedDOF
-        # print('kCoeff: ', kCoeff)
-        
+
         rows, columns = getRowsColumns(kCoeff, nMatrixDofs)
 
         rowsForStiffnessSparseMatrix[startIndexStiffness:startIndexStiffness+rows.size] = rows
@@ -279,19 +261,18 @@ def getGlobalStiffnesAndForce(elementsList,platesList,downStandBeamsList, nodesR
 
     #if line load, assemble HERE load vector
     if p.case == 'line':
-        rowsForForceSparseMatrix,dataForForceSparseMatrix = getLineLoadForceVector(p,nSparseData,elemNodesRotations)
-
+        rowsForForceSparseMatrix,dataForForceSparseMatrix = _getLineLoadForceVector(p,nSparseData,elemNodesRotations)
     elif p.case == 'nodes':
-        rowsForForceSparseMatrix,dataForForceSparseMatrix = getNodesLoadForceVector(p, nSparseData)
+        rowsForForceSparseMatrix,dataForForceSparseMatrix = _getNodesLoadForceVector(p, nSparseData)
     elif p.case == 'point':
-        rowsForForceSparseMatrix,dataForForceSparseMatrix = getPointLoadForceVector(p, nSparseData)
+        rowsForForceSparseMatrix,dataForForceSparseMatrix = _getPointLoadForceVector(p, nSparseData)
 
     # create global matrixes
     sparseGlobalMatrix = csr_matrix((dataForStiffnessSparseMatrix,(rowsForStiffnessSparseMatrix,columnsForStiffnessSparseMatrix)))
     sparseForceGlobal = csr_matrix((dataForForceSparseMatrix,(rowsForForceSparseMatrix,columnsForForceSparseMatrix)), shape=(nNodesTotal*3,1))
     return sparseGlobalMatrix, sparseForceGlobal, discartedDOFs
 
-def getLineLoadForceVector(p,nSparseData,elemNodesRotations):
+def _getLineLoadForceVector(p,nSparseData,elemNodesRotations):
     ''' Computes informations required to create the sparse force vector in case of line loads. \n
         Input: \n
             * p: Load object. \n
@@ -347,7 +328,7 @@ def getLineLoadForceVector(p,nSparseData,elemNodesRotations):
         startIndexForce += kCoeff.size
     return rowsForForceSparseMatrix,dataForForceSparseMatrix
 
-def getNodesLoadForceVector(p, nSparseData):
+def _getNodesLoadForceVector(p, nSparseData):
     ''' Computes informations required to create the sparse force vector in case the user manually defines the node loads. \n
         Input: \n
             * p: Load object. \n
@@ -371,7 +352,7 @@ def getNodesLoadForceVector(p, nSparseData):
         startIndexForce += 3
     return rowsForForceSparseMatrix,dataForForceSparseMatrix 
 
-def getPointLoadForceVector(p,nSparseData):
+def _getPointLoadForceVector(p,nSparseData):
     ''' Computes informations required to create the sparse force vector in case of line loads. \n
         Input: \n
             * p: Load object. \n
@@ -406,7 +387,7 @@ def getPointLoadForceVector(p,nSparseData):
 
     return rowsForForceSparseMatrix,dataForForceSparseMatrix
 
-def getFreeDOFvector(BCs, nGDofs,elementType,discartedDOFs):
+def _getFreeDOFvector(BCs, nGDofs,elementType,discartedDOFs):
     ''' Constructs the vector with the not-restrained degrees of freedom.\n
         Input: \n
             * BCs: n x 4 numpy array. n is the number of restrained nodes, the first column is the node tag, the other column represent the condition of the three DOFs (1 is blocked, 0 is free). \n
@@ -441,7 +422,7 @@ def getFreeDOFvector(BCs, nGDofs,elementType,discartedDOFs):
 
     return fDofsInt, rDofsBool,keepedDisplacements
 
-def assembleSystemMFCmatrix(AmatList):
+def _assembleSystemMFCmatrix(AmatList):
     ''' Constructs the MFC matrix for the system. \n
         Input: \n
             * AmatList: List of MFC matrix for the indivudual downstand beams. \n
@@ -456,7 +437,7 @@ def assembleSystemMFCmatrix(AmatList):
             A= np.concatenate((A, myA))
     return A
 
-def getMmatrixAndRightSide(A, kMatFree,fVecFree):
+def _getMmatrixAndRightSide(A, kMatFree,fVecFree):
     ''' Returns left and right sides of the system of equations to solve. \n
             Input: \n
                 * A: System MFC matrix of shape (nConstraints x nGDOFs). \n
@@ -477,7 +458,7 @@ def getMmatrixAndRightSide(A, kMatFree,fVecFree):
 
     return M, rightSide
 
-def getBendingResistance(bendingMoments,kBendingResistance):
+def _getBendingResistance(bendingMoments,kBendingResistance):
     '''Computes rquired bending resistance according to SIA 262.\n
         Input: \n
             * bendingMoments: Numpy array of shape (n evaluation points, 3). First column: mx, second column: my, third column: mxy. \n
@@ -495,25 +476,42 @@ def getBendingResistance(bendingMoments,kBendingResistance):
     return bendingResistance
 
 def computeBeamComponents(self, startCoord, endCoord, nEvaluationPoints,resultsScales = (1,1, 1),integrationWidth = 0, nIntegrationPoints =0):
+    '''Computes the results over a custom-defined line.
 
+    ~~~~~~~~~~~~~~~~~~~
+    INPUT
+    ~~~~~~~~~~~~~~~~~~~
+
+    * **self**: `PlateModel` object.
+    * **startCoord**: tuple with (x,y) coordinates defining the starting point of the line.
+    * **endCoord**: tuple with (x,y) coordinates defining the ending point of the line. 
+    * **resultsScales = (1e-3, 1, 1)**: Before being displayed the computed displacements are 
+    multiplied by resultsScales[0], the computed beding moments are multiplied by resultsScales[1]
+    and the shear forces by resultsScales[2]. 
+    * **integrationWidth = 0**: if > 0, the values on a line normal to the main cut of length +-integrationWidth/2 are evaluated and 
+    integrated to a single value, which will then be displayed. 
+    * **nIntegrationPoint=0**: number of point for the integration normal to the direction of the main cut.
+
+    ~~~~~~~~~~~~~~~~~~~
+    RETURN
+    ~~~~~~~~~~~~~~~~~~~
+
+    * **bendingMoments**: (nPoints, 3) Numpy array containing Mx, My and Mxy for each evaluation point.
+    * **shearForces**: (nPoints, 2) Numpy array containing Vx and Vy for each evaluation point.
+    * **arrayEvaluationPoints**: (nPoints, 2) Numpy array containing x and y coordinates of each evaluation point.
+    '''
     uGlob = self.resultsInformation.uGlobPlate
-    # print(uGlob)
-
     elementsList = self.mesh.elementsList
     arrayEvaluationPoints = np.zeros((nEvaluationPoints,2))
-
     arrayEvaluationPoints[:,0] = np.linspace(startCoord[0], endCoord[0], num=nEvaluationPoints)
     arrayEvaluationPoints[:,1] = np.linspace(startCoord[1], endCoord[1], num=nEvaluationPoints)
-    
     bendingMoments = np.zeros((nEvaluationPoints,3))
     shearForces = np.zeros((nEvaluationPoints,2))
     verticalDisplacements = np.zeros(nEvaluationPoints)
 
-
     if integrationWidth ==0:
         for k,evaluationPoint in enumerate(arrayEvaluationPoints):
             elementTaggetEl, elementTypegetEl, nodeTagsgetEl, ugetEl, vgetEl, wgetEl = gmsh.model.mesh.getElementByCoordinates(evaluationPoint[0],evaluationPoint[1],0, dim=2)
-            # print('element: ', elementTaggetEl)
             element = self.mesh.getElementByTagDictionary[elementTaggetEl]
             plateOfTheElement = element.whichPlate
             elementType = element.type
@@ -527,7 +525,6 @@ def computeBeamComponents(self, startCoord, endCoord, nEvaluationPoints,resultsS
             for i in range(0,3):
                 kCoeff[0+i::3]=coherentElemNodes*3+i
             vLoc = np.matmul(element.rotationMatrix, uGlob[kCoeff])
-            # print('vLoc: ', vLoc)
             Df = self.plates[plateOfTheElement].Df
             Dc = self.plates[plateOfTheElement].Dc
 
@@ -547,7 +544,6 @@ def computeBeamComponents(self, startCoord, endCoord, nEvaluationPoints,resultsS
         lineDir = np.array([endCoord[0]-startCoord[0],endCoord[1]-startCoord[1]])
         lineDir = lineDir/np.sqrt(lineDir[0]**2+lineDir[1]**2)
         normLineDir = np.array([lineDir[1], -lineDir[0]])
-
         for k,evaluationPoint in enumerate(arrayEvaluationPoints):
             pCord = np.array([evaluationPoint[0],evaluationPoint[1]])
             startIntegrationLine = pCord-normLineDir*integrationWidth/2
@@ -575,15 +571,12 @@ def computeBeamComponents(self, startCoord, endCoord, nEvaluationPoints,resultsS
                 for i in range(0,3):
                     kCoeff[0+i::3]=coherentElemNodes*3+i
                 vLoc = np.matmul(element.rotationMatrix, uGlob[kCoeff])
-                # print('vLoc: ', vLoc)
                 Df = self.plates[plateOfTheElement].Df
                 Dc = self.plates[plateOfTheElement].Dc
 
                 ri = -ugetEl
                 si = -vgetEl
-
                 N, Bb,Bs, detJ =getShapeFunctionForElementType(elementType,ri, si, xi, yi)
-
                 integrationBendingMoments[j,0:3] = np.matmul(Df,np.matmul(Bb, vLoc))[:,0]*1
                 integrationShearForces[j,0:2] = np.matmul(Dc, np.matmul(Bs, vLoc))[:,0]*1
             
@@ -598,23 +591,35 @@ def computeBeamComponents(self, startCoord, endCoord, nEvaluationPoints,resultsS
     resultsDictionary = self.resultsInformation.resultsDictionary
     xPos = arrayEvaluationPoints[:,0]
     yPos = arrayEvaluationPoints[:,1]
-    resultsDictionary['vDisp_line'] = Result(xPos,yPos, verticalDisplacements, resultsScales[0])
-    resultsDictionary['Mx_line'] = Result(xPos,yPos,bendingMoments[:,0], resultsScales[1])
-    resultsDictionary['My_line'] = Result(xPos,yPos,bendingMoments[:,1], resultsScales[1])
-    resultsDictionary['Mxy_line'] = Result(xPos,yPos,bendingMoments[:,2], resultsScales[1])
-    resultsDictionary['Vx_line'] = Result(xPos,yPos,shearForces[:,0], resultsScales[2])
-    resultsDictionary['Vy_line'] = Result(xPos,yPos,shearForces[:,1], resultsScales[2])
-
-
-    # self.results.schnittList[lineName] = Schnitt(bendingMoments, shearForces,verticalDisplacements, arrayEvaluationPoints)
+    resultsDictionary['vDisp_line'] = _Result(xPos,yPos, verticalDisplacements, resultsScales[0])
+    resultsDictionary['Mx_line'] = _Result(xPos,yPos,bendingMoments[:,0], resultsScales[1])
+    resultsDictionary['My_line'] = _Result(xPos,yPos,bendingMoments[:,1], resultsScales[1])
+    resultsDictionary['Mxy_line'] = _Result(xPos,yPos,bendingMoments[:,2], resultsScales[1])
+    resultsDictionary['Vx_line'] = _Result(xPos,yPos,shearForces[:,0], resultsScales[2])
+    resultsDictionary['Vy_line'] = _Result(xPos,yPos,shearForces[:,1], resultsScales[2])
 
     return bendingMoments, shearForces, arrayEvaluationPoints
 
-
 def evaluateAtPoints(self, coords, displayPoints = False):
+    '''
+    Computes the displacement, rotation and internal forces at the location contained in coords.
 
+    ~~~~~~~~~~~~~~~~~~~
+    INPUT
+    ~~~~~~~~~~~~~~~~~~~
+
+    * **coords**: Numpy array of shape (nPoints, 2) with the x,y coordinates of the points to be evaluated. 
+    * **displayPoints = False**: If True, plots the requested evaluation points on the inputGeometry. 
+
+    ~~~~~~~~~~~~~~~~~~~
+    RETURN
+    ~~~~~~~~~~~~~~~~~~~
+
+    * **vericalDisplacements**: (nPoints, 1) Numpy array containing vertical displacements of each evaluation point.
+    * **bendingMoments**: (nPoints, 3) Numpy array containing Mx, My and Mxy for each evaluation point.
+    * **shearForces**: (nPoints, 2) Numpy array containing Vx and Vy for each evaluation point.
+    '''
     uGlob = self.resultsInformation.uGlobPlate
-    # print(uGlob)
     nEvaluationPoints = coords.shape[0]
     elementsList = self.mesh.elementsList
     arrayEvaluationPoints = np.zeros((nEvaluationPoints,2))
@@ -623,10 +628,8 @@ def evaluateAtPoints(self, coords, displayPoints = False):
     shearForces = np.zeros((nEvaluationPoints,2))
     verticalDisplacements = np.zeros(nEvaluationPoints)
     resultsScaleVertDisp = self.resultsInformation.resultsDictionary['vDisp'].resultScale
-
     for k,evaluationPoint in enumerate(coords):
         elementTaggetEl, elementTypegetEl, nodeTagsgetEl, ugetEl, vgetEl, wgetEl = gmsh.model.mesh.getElementByCoordinates(evaluationPoint[0],evaluationPoint[1],0, dim=2)
-        # print('element: ', elementTaggetEl)
         element = self.mesh.getElementByTagDictionary[elementTaggetEl]
         plateOfTheElement = element.whichPlate
         elementType = element.type
@@ -638,10 +641,7 @@ def evaluateAtPoints(self, coords, displayPoints = False):
         elementShape = len(xi)
         kCoeff, discartedDOF = getKCoeff(elementType, coherentElemNodes)
 
-
-        # vLoc = np.matmul(element.rotationMatrix, uGlob[kCoeff])
         vLoc = uGlob[kCoeff]
-        # print('vLoc: ', vLoc)
         Df = self.plates[plateOfTheElement].Df
         Dc = self.plates[plateOfTheElement].Dc
         if elementType == 'MITC':
@@ -650,18 +650,13 @@ def evaluateAtPoints(self, coords, displayPoints = False):
         else:
             ri =ugetEl
             si = vgetEl
-        
-
         if elementType == 'DB' and nNodes ==4:
             ri = np.array([ri])
             si = np.array([si])
-
         N, Bb,Bs, detJ =getShapeFunctionForElementType(elementType,ri, si, xi, yi)
-
         tempDispl = N@vLoc
         if len(tempDispl.shape)>2:
             tempDispl = tempDispl[0,:,:]
-
         if (elementType == 'DB' and nNodes ==9) or (elementType == 'MITC' and nNodes==9):
             changeSign = -1
         else:
@@ -672,22 +667,40 @@ def evaluateAtPoints(self, coords, displayPoints = False):
 
     if displayPoints:
         fig,outAx = plotInputGeometry(self)
-        # fig,outAx = plotMesh(self)
         for k,evaluationPoint in enumerate(coords):
             outAx.scatter(evaluationPoint[0],evaluationPoint[1], facecolor='b', marker='.')
-
     return verticalDisplacements,bendingMoments, shearForces
 
-class Schnitt:
+class _Schnitt:
     def __init__(self, bendingMoments, shearForces,verticalDisplacements, arrayEvaluationPoints):
+        ''' Class containing the results (displacements and internal forces) along a line cut.\n
+        Input: \n
+        * bendingMoments: Numpy array of shape (nEvaluationPoints, 3) \n
+        * shearForces: Numpy array of shape (nEvaluationPoints, 2) \n
+        * verticalDisplacements: Numpy array of shape (nEvaluationPoints, 1) \n
+        * arrayEvaluationPoints: Numpy array of shape (nEvaluationPoints, 2) with the x y coordinates of the evaluation points. \n
+        '''
         self.bendingMoments = bendingMoments
         self.shearForces = shearForces
         self.verticalDisplacements = verticalDisplacements
         self.arrayEvaluationPoints = arrayEvaluationPoints
 
 
-class Result:
+class _Result:
+    '''
+    Attributes: \n
+    * iMax, zMax
+    * iMin, zMin
+    * zMaxScaled, zMinScaled, zAbsScaled
+    '''
     def __init__(self,x,y,z, resultScale):
+        '''Class object to store results \n
+        Inputs: \n
+        * x \n
+        * y \n
+        * z \n
+        * resultScale: Scaling factor for the display of the result. \n
+        '''
         self.x = x
         self.y = y
         self.z = z
@@ -706,12 +719,12 @@ class Result:
 
 class ResultsInformation:
     def __init__(self):
+        '''Stores all kind of object regarding results.
+        '''
         self.resultsDictionary = None
-
         self.bendingMoments = None
         self.internalForcesPositions = None
         self.shearForces = None
-        # self.resultsScaleVertDisp = resultsScale[0]
         self.bendingResistance = None
         self.bendingMomentsDSB=None
         self.internalForcesPositionsDSB=None
